@@ -23,7 +23,7 @@
 #include <libgda/gda-data-handler.h>
 #include <gdk/gdkkeysyms.h>
 #include <string.h>
-#include "gdaui-format-entry.h"
+#include "gdaui-formatted-entry.h"
 
 /* 
  * Main static functions 
@@ -34,19 +34,19 @@ static void gdaui_entry_common_time_dispose (GObject *object);
 static void gdaui_entry_common_time_finalize (GObject *object);
 
 static void gdaui_entry_common_time_set_property (GObject *object,
-					guint param_id,
-					const GValue *value,
-					GParamSpec *pspec);
+						  guint param_id,
+						  const GValue *value,
+						  GParamSpec *pspec);
 static void gdaui_entry_common_time_get_property (GObject *object,
-					guint param_id,
-					GValue *value,
-					GParamSpec *pspec);
+						  guint param_id,
+						  GValue *value,
+						  GParamSpec *pspec);
 
 /* properties */
 enum
 {
 	PROP_0,
-	PROP_EDITING_CANCELLED,
+	PROP_EDITING_CANCELED,
 	PROP_TYPE
 };
 
@@ -75,6 +75,7 @@ struct _GdauiEntryCommonTimePrivate
 	GtkWidget *date;
         GtkWidget *window;
         GtkWidget *date_button;
+	gboolean   editing_canceled;
 
 	/* for time */
 	GtkWidget *entry_time;
@@ -144,15 +145,23 @@ gdaui_entry_common_time_class_init (GdauiEntryCommonTimeClass * class)
 	object_class->set_property = gdaui_entry_common_time_set_property;
 	object_class->get_property = gdaui_entry_common_time_get_property;
 
-	g_object_class_install_property (object_class, PROP_EDITING_CANCELLED,
-					 g_param_spec_boolean ("editing_cancelled", NULL, NULL, FALSE, G_PARAM_READABLE));
+	g_object_class_install_property (object_class, PROP_EDITING_CANCELED,
+					 g_param_spec_boolean ("editing-canceled", NULL, NULL, FALSE, G_PARAM_READABLE));
 	g_object_class_install_property (object_class, PROP_TYPE,
 					 g_param_spec_uint ("type", NULL, NULL, 0, G_MAXUINT, GDA_TYPE_TIME, 
 							    G_PARAM_WRITABLE | G_PARAM_READABLE));
 }
 
+static gboolean
+key_press_event_cb (GdauiEntryCommonTime *mgtim, GdkEventKey *key_event, gpointer data)
+{
+	if (key_event->keyval == GDK_Escape)
+		mgtim->priv->editing_canceled = TRUE;
+	return FALSE;
+}
+
 static void
-gdaui_entry_common_time_init (GdauiEntryCommonTime * gdaui_entry_common_time)
+gdaui_entry_common_time_init (GdauiEntryCommonTime *gdaui_entry_common_time)
 {
 	gdaui_entry_common_time->priv = g_new0 (GdauiEntryCommonTimePrivate, 1);
 	gdaui_entry_common_time->priv->entry_date = NULL;
@@ -162,6 +171,9 @@ gdaui_entry_common_time_init (GdauiEntryCommonTime * gdaui_entry_common_time)
 	gdaui_entry_common_time->priv->date_button = NULL;
 	gdaui_entry_common_time->priv->hbox = NULL;
 	gdaui_entry_common_time->priv->last_value_set = NULL;
+	gdaui_entry_common_time->priv->editing_canceled = FALSE;
+	g_signal_connect (gdaui_entry_common_time, "key-press-event",
+			  G_CALLBACK (key_press_event_cb), NULL);
 }
 
 /**
@@ -234,9 +246,9 @@ gdaui_entry_common_time_finalize (GObject   * object)
 
 static void
 gdaui_entry_common_time_set_property (GObject *object,
-					 guint param_id,
-					 const GValue *value,
-					 GParamSpec *pspec)
+				      guint param_id,
+				      const GValue *value,
+				      GParamSpec *pspec)
 {
 	GdauiEntryCommonTime *mgtim;
 
@@ -255,24 +267,17 @@ gdaui_entry_common_time_set_property (GObject *object,
 
 static void
 gdaui_entry_common_time_get_property (GObject *object,
-					 guint param_id,
-					 GValue *value,
-					 GParamSpec *pspec)
+				      guint param_id,
+				      GValue *value,
+				      GParamSpec *pspec)
 {
 	GdauiEntryCommonTime *mgtim;
-	gboolean cancelled;
 
 	mgtim = GDAUI_ENTRY_COMMON_TIME (object);
 	if (mgtim->priv) {
 		switch (param_id) {
-		case PROP_EDITING_CANCELLED:
-			cancelled = FALSE;
-			/* FIXME */
-			if (mgtim->priv->entry_date)
-				cancelled = GTK_ENTRY (mgtim->priv->entry_date)->editing_canceled;
-			if (!cancelled && mgtim->priv->entry_time)
-				cancelled = GTK_ENTRY (mgtim->priv->entry_time)->editing_canceled;
-			g_value_set_boolean (value, cancelled);
+		case PROP_EDITING_CANCELED:
+			g_value_set_boolean (value, mgtim->priv->editing_canceled);
 			break;
 		case PROP_TYPE:
 			g_value_set_uint (value, gdaui_data_entry_get_value_type (GDAUI_DATA_ENTRY (object)));
@@ -328,51 +333,51 @@ real_set_value (GdauiEntryWrapper *mgwrap, const GValue *value)
 	if (type == G_TYPE_DATE) {
 		if (value) {
 			if (gda_value_is_null ((GValue *) value))
-				gdaui_format_entry_set_text (GDAUI_FORMAT_ENTRY (mgtim->priv->entry_date), NULL);
+				gdaui_entry_set_text (GDAUI_ENTRY (mgtim->priv->entry_date), NULL);
 			else {
 				gchar *str;
 				
 				str = gda_data_handler_get_str_from_value (dh, value);
-				gtk_entry_set_text (GTK_ENTRY (mgtim->priv->entry_date), str);
+				gdaui_entry_set_text (GDAUI_ENTRY (mgtim->priv->entry_date), str);
 				g_free (str);
 			}
 		}
 		else 
-			gdaui_format_entry_set_text (GDAUI_FORMAT_ENTRY (mgtim->priv->entry_date), NULL);
+			gdaui_entry_set_text (GDAUI_ENTRY (mgtim->priv->entry_date), NULL);
 	}
 	else if (type == GDA_TYPE_TIME) {
 		if (value) {
 			if (gda_value_is_null ((GValue *) value))
-				gdaui_format_entry_set_text (GDAUI_FORMAT_ENTRY (mgtim->priv->entry_time), NULL);
+				gdaui_entry_set_text (GDAUI_ENTRY (mgtim->priv->entry_time), NULL);
 			else {
 				gchar *str;
 				
 				str = gda_data_handler_get_str_from_value (dh, value);
-				gtk_entry_set_text (GTK_ENTRY (mgtim->priv->entry_time), str);
+				gdaui_entry_set_text (GDAUI_ENTRY (mgtim->priv->entry_time), str);
 				g_free (str);
 			}
 		}
 		else 
-			gdaui_format_entry_set_text (GDAUI_FORMAT_ENTRY (mgtim->priv->entry_time), NULL);
+			gdaui_entry_set_text (GDAUI_ENTRY (mgtim->priv->entry_time), NULL);
 	}
 	else if (type == GDA_TYPE_TIMESTAMP) {
 		if (value) {
 			if (gda_value_is_null ((GValue *) value))
-				gdaui_format_entry_set_text (GDAUI_FORMAT_ENTRY (mgtim->priv->entry_time), NULL);
+				gdaui_entry_set_text (GDAUI_ENTRY (mgtim->priv->entry_time), NULL);
 			else {
 				gchar *str, *ptr;
 				
 				str = gda_data_handler_get_str_from_value (dh, value);
 				ptr = strtok (str, " ");
-				gdaui_format_entry_set_text (GDAUI_FORMAT_ENTRY (mgtim->priv->entry_date), ptr);
+				gdaui_entry_set_text (GDAUI_ENTRY (mgtim->priv->entry_date), ptr);
 				ptr = strtok (NULL, " ");
-				gdaui_format_entry_set_text (GDAUI_FORMAT_ENTRY (mgtim->priv->entry_time), ptr);
+				gdaui_entry_set_text (GDAUI_ENTRY (mgtim->priv->entry_time), ptr);
 				g_free (str);
 			}
 		}
 		else {
-			gdaui_format_entry_set_text (GDAUI_FORMAT_ENTRY (mgtim->priv->entry_date), NULL);
-			gdaui_format_entry_set_text (GDAUI_FORMAT_ENTRY (mgtim->priv->entry_time), NULL);
+			gdaui_entry_set_text (GDAUI_ENTRY (mgtim->priv->entry_date), NULL);
+			gdaui_entry_set_text (GDAUI_ENTRY (mgtim->priv->entry_time), NULL);
 		}
 	}
 	else
@@ -404,12 +409,12 @@ real_get_value (GdauiEntryWrapper *mgwrap)
 	dh = gdaui_data_entry_get_handler (GDAUI_DATA_ENTRY (mgwrap));
 
 	if (type == G_TYPE_DATE) {
-		str2 = gdaui_format_entry_get_text (GDAUI_FORMAT_ENTRY (mgtim->priv->entry_date));
+		str2 = gdaui_formatted_entry_get_text (GDAUI_FORMATTED_ENTRY (mgtim->priv->entry_date));
 		value = gda_data_handler_get_value_from_str (dh, str2, type); /* FIXME: not SQL but STR */
 		g_free (str2);
 	}
 	else if (type == GDA_TYPE_TIME) {
-		str2 = gdaui_format_entry_get_text (GDAUI_FORMAT_ENTRY (mgtim->priv->entry_time));
+		str2 = gdaui_formatted_entry_get_text (GDAUI_FORMATTED_ENTRY (mgtim->priv->entry_time));
 		value = gda_data_handler_get_value_from_str (dh, str2, type);
 		if (value && (G_VALUE_TYPE (value) != GDA_TYPE_NULL) &&
 		    mgtim->priv->last_value_set && 
@@ -427,8 +432,8 @@ real_get_value (GdauiEntryWrapper *mgwrap)
 	else if (type == GDA_TYPE_TIMESTAMP) {
 		gchar *tmpstr, *tmpstr2;
 
-		tmpstr = gdaui_format_entry_get_text (GDAUI_FORMAT_ENTRY (mgtim->priv->entry_time));
-		tmpstr2 = gdaui_format_entry_get_text (GDAUI_FORMAT_ENTRY (mgtim->priv->entry_date));
+		tmpstr = gdaui_formatted_entry_get_text (GDAUI_FORMATTED_ENTRY (mgtim->priv->entry_time));
+		tmpstr2 = gdaui_formatted_entry_get_text (GDAUI_FORMATTED_ENTRY (mgtim->priv->entry_date));
 		str2 = g_strdup_printf ("%s %s", tmpstr2, tmpstr);
 		g_free (tmpstr);
 		g_free (tmpstr2);
@@ -547,7 +552,6 @@ grab_focus (GdauiEntryWrapper *mgwrap)
 /*
  * callbacks for the date 
  */
-
 static void internal_set_time (GtkWidget *widget, GdauiEntryCommonTime *mgtim);
 static gint date_delete_popup (GtkWidget *widget, GdauiEntryCommonTime *mgtim);
 static gint date_key_press_popup (GtkWidget *widget, GdkEventKey *event, GdauiEntryCommonTime *mgtim);
@@ -556,6 +560,8 @@ static void date_day_selected (GtkCalendar *calendar, GdauiEntryCommonTime *mgti
 static void date_day_selected_double_click (GtkCalendar *calendar, GdauiEntryCommonTime *mgtim);
 static void date_calendar_choose_cb (GtkWidget *button, GdauiEntryCommonTime *mgtim);
 
+static void entry_date_insert_func (GdauiFormattedEntry *fentry, gunichar insert_char, gint virt_pos, gpointer data);
+
 static GtkWidget *
 create_entry_date (GdauiEntryCommonTime *mgtim)
 {
@@ -567,14 +573,23 @@ create_entry_date (GdauiEntryCommonTime *mgtim)
 
 	/* text entry */
 	dh = gdaui_data_entry_get_handler (GDAUI_DATA_ENTRY (mgtim));
-	wid = gdaui_format_entry_new ();
 	if (GDA_IS_HANDLER_TIME (dh)) {
-		gchar *str;
+		gchar *str, *mask, *ptr;
 		str = gda_handler_time_get_format (GDA_HANDLER_TIME (dh), G_TYPE_DATE);
-		gdaui_format_entry_set_format (GDAUI_FORMAT_ENTRY (wid), str, NULL, NULL);
-		gtk_entry_set_width_chars (GTK_ENTRY (wid), g_utf8_strlen (str, -1));
+		mask = g_strdup (str);
+		for (ptr = mask; *ptr; ptr++) {
+			if (*ptr == '0')
+				*ptr = '-';
+		}
+		wid = gdaui_formatted_entry_new (str, mask);
 		g_free (str);
+		g_free (mask);
+
+		gdaui_formatted_entry_set_insert_func (GDAUI_FORMATTED_ENTRY (wid), entry_date_insert_func,
+						       mgtim);
 	}
+	else
+		wid = gdaui_entry_new (NULL, NULL);
 	gtk_box_pack_start (GTK_BOX (hb), wid, FALSE, FALSE, 0);
 	gtk_widget_show (wid);
 	mgtim->priv->entry_date = wid;
@@ -585,11 +600,11 @@ create_entry_date (GdauiEntryCommonTime *mgtim)
 	window = gtk_window_new (GTK_WINDOW_POPUP);
 	gtk_widget_set_events (window, gtk_widget_get_events (window) | GDK_KEY_PRESS_MASK);
 	gtk_window_set_resizable (GTK_WINDOW (window), FALSE);
-	g_signal_connect (G_OBJECT (window), "delete_event",
+	g_signal_connect (G_OBJECT (window), "delete-event",
 			  G_CALLBACK (date_delete_popup), mgtim);
-	g_signal_connect (G_OBJECT (window), "key_press_event",
+	g_signal_connect (G_OBJECT (window), "key-press-event",
 			  G_CALLBACK (date_key_press_popup), mgtim);
-	g_signal_connect (G_OBJECT (window), "button_press_event",
+	g_signal_connect (G_OBJECT (window), "button-press-event",
 			  G_CALLBACK (date_button_press_popup), mgtim);
 	mgtim->priv->window = window;
 	
@@ -598,9 +613,9 @@ create_entry_date (GdauiEntryCommonTime *mgtim)
 	mgtim->priv->date = wid;
 	gtk_container_add (GTK_CONTAINER (window), wid);
 	gtk_widget_show (wid);
-	g_signal_connect (G_OBJECT (wid), "day_selected",
+	g_signal_connect (G_OBJECT (wid), "day-selected",
 			  G_CALLBACK (date_day_selected), mgtim);
-	g_signal_connect (G_OBJECT (wid), "day_selected_double_click",
+	g_signal_connect (G_OBJECT (wid), "day-selected-double-click",
 			  G_CALLBACK (date_day_selected_double_click), mgtim);
 	
 	/* button to pop up the calendar */
@@ -621,6 +636,85 @@ create_entry_date (GdauiEntryCommonTime *mgtim)
 	return hb;
 }
 
+static void
+entry_date_insert_func (GdauiFormattedEntry *fentry, gunichar insert_char, gint virt_pos, gpointer data)
+{
+	GValue *value;
+	GType type;
+
+	type = gdaui_data_entry_get_value_type (GDAUI_DATA_ENTRY (data));
+	value = real_get_value (GDAUI_ENTRY_WRAPPER (data));
+	if (!value)
+		return;
+
+	if (G_VALUE_TYPE (value) == GDA_TYPE_NULL) {
+		if (type == G_TYPE_DATE) {
+			/* set current date, whatever @insert_char is */
+			GDate *ndate;
+			ndate = g_new0 (GDate, 1);
+			g_date_set_time_t (ndate, time (NULL));
+
+			gda_value_reset_with_type (value, type);
+			g_value_take_boxed (value, ndate);
+			real_set_value (GDAUI_ENTRY_WRAPPER (data), value);
+		}
+		else if (type == GDA_TYPE_TIMESTAMP) {
+			GValue *tsvalue;
+			tsvalue = gda_value_new_timestamp_from_timet (time (NULL));
+			real_set_value (GDAUI_ENTRY_WRAPPER (data), tsvalue);
+			gda_value_free (tsvalue);
+		}
+	}
+	else {
+		GDate *date = NULL;
+		if (type == G_TYPE_DATE) {
+			date = (GDate*) g_value_get_boxed (value);
+		}
+		else if (type == GDA_TYPE_TIMESTAMP) {
+			const GdaTimestamp *ts;
+			ts = gda_value_get_timestamp (value);
+			date = g_date_new_dmy (ts->day, ts->month, ts->year);
+		}
+
+		if (date) {
+			GDate *ndate;
+			gboolean changed = FALSE;
+
+			ndate = g_new (GDate, 1);
+			*ndate = *date;
+			if ((insert_char == g_utf8_get_char ("+")) ||
+			    (insert_char == g_utf8_get_char ("="))) {
+				g_date_add_days (ndate, 1);
+				changed = TRUE;
+			}
+			else if ((insert_char == g_utf8_get_char ("-")) ||
+				 (insert_char == g_utf8_get_char ("6"))) {
+				g_date_subtract_days (ndate, 1);
+				changed = TRUE;
+			}
+
+			if (changed) {
+				if (type == G_TYPE_DATE) {
+					g_value_take_boxed (value, ndate);
+				}
+				else if (type == GDA_TYPE_TIMESTAMP) {
+					GdaTimestamp *ts;
+					ts = (GdaTimestamp*) gda_timestamp_copy ((gpointer) gda_value_get_timestamp (value));
+					ts->day = g_date_get_day (ndate);
+					ts->month = g_date_get_month (ndate);
+					ts->year = g_date_get_year (ndate);
+					g_date_free (date);
+					g_date_free (ndate);
+					gda_value_set_timestamp (value, ts);
+					gda_timestamp_free (ts);
+				}
+				real_set_value (GDAUI_ENTRY_WRAPPER (data), value);
+			}
+		}
+	}
+	gda_value_free (value);
+}
+
 static void
 internal_set_time (GtkWidget *widget, GdauiEntryCommonTime *mgtim)
 {
@@ -633,17 +727,19 @@ internal_set_time (GtkWidget *widget, GdauiEntryCommonTime *mgtim)
 	type = gdaui_data_entry_get_value_type (GDAUI_DATA_ENTRY (mgtim));
 	if (type == GDA_TYPE_TIMESTAMP) {
 		GdaDataHandler *dh;
-		gchar *str;
+		gchar *str, *str2;
 		GValue *value;
 
 		dh = gdaui_data_entry_get_handler (GDAUI_DATA_ENTRY (mgtim));
-		str = gdaui_format_entry_get_text (GDAUI_FORMAT_ENTRY (mgtim->priv->entry_time));
-		value = gda_data_handler_get_value_from_str (dh, str, type);
+		str = gdaui_formatted_entry_get_text (GDAUI_FORMATTED_ENTRY (mgtim->priv->entry_time));
+		str2 = g_strdup_printf ("01.01.2000 %s", str);
+		g_free (str);
+		value = gda_data_handler_get_value_from_str (dh, str2, type);
 		if (!value || gda_value_is_null (value)) 
-			gdaui_format_entry_set_text (GDAUI_FORMAT_ENTRY (mgtim->priv->entry_time), "00:00:00");
+			gdaui_entry_set_text (GDAUI_ENTRY (mgtim->priv->entry_time), "00:00:00");
 		if (value)
 			gda_value_free (value);
-		g_free (str);
+		g_free (str2);
 	}
 }
 
@@ -667,7 +763,7 @@ date_key_press_popup (GtkWidget *widget, GdkEventKey *event, GdauiEntryCommonTim
 	if (event->keyval != GDK_Escape)
                 return FALSE;
 
-        g_signal_stop_emission_by_name (widget, "key_press_event");
+        g_signal_stop_emission_by_name (widget, "key-press-event");
         hide_popup (mgtim);
 
         return TRUE;
@@ -691,7 +787,7 @@ date_button_press_popup (GtkWidget *widget, GdkEventButton *event, GdauiEntryCom
                 while (child) {
                         if (child == widget)
                                 return FALSE;
-                        child = child->parent;
+                        child = gtk_widget_get_parent (child);
                 }
         }
 
@@ -722,7 +818,7 @@ date_day_selected (GtkCalendar *calendar, GdauiEntryCommonTime *mgtim)
         buffer[sizeof(buffer)-1] = '\0';
 
         str_utf8 = g_locale_to_utf8 (buffer, -1, NULL, NULL, NULL);
-        gdaui_format_entry_set_text (GDAUI_FORMAT_ENTRY (mgtim->priv->entry_date), str_utf8);
+        gdaui_entry_set_text (GDAUI_ENTRY (mgtim->priv->entry_date), str_utf8);
         g_free (str_utf8);
 }
 
@@ -796,8 +892,14 @@ date_calendar_choose_cb (GtkWidget *button, GdauiEntryCommonTime *mgtim)
 
         /* popup window */
         /* Temporarily grab pointer and keyboard, copied from GnomeDateEdit */
-        if (!popup_grab_on_window (button->window, gtk_get_current_event_time ()))
+#if GTK_CHECK_VERSION(2,18,0)
+        if (!popup_grab_on_window (gtk_widget_get_window (button), gtk_get_current_event_time ()))
                 return;
+#else
+	if (!popup_grab_on_window (button->window, gtk_get_current_event_time ()))
+		return;
+#endif
+
         position_popup (mgtim);
         gtk_grab_add (mgtim->priv->window);
         gtk_widget_show (mgtim->priv->window);
@@ -838,8 +940,13 @@ date_calendar_choose_cb (GtkWidget *button, GdauiEntryCommonTime *mgtim)
 		gtk_window_move (GTK_WINDOW (mgtim->priv->window), root_x, root_y);
 
         gtk_widget_grab_focus (mgtim->priv->date);
-        popup_grab_on_window (mgtim->priv->window->window,
+#if GTK_CHECK_VERSION(2,18,0)
+        popup_grab_on_window (gtk_widget_get_window (mgtim->priv->window),
                               gtk_get_current_event_time ());
+#else
+	popup_grab_on_window (mgtim->priv->window->window,
+			      gtk_get_current_event_time ());
+#endif
 }
 
 static gboolean
@@ -869,12 +976,22 @@ position_popup (GdauiEntryCommonTime *mgtim)
 
         gtk_widget_size_request (mgtim->priv->window, &req);
 
-        gdk_window_get_origin (mgtim->priv->date_button->window, &x, &y);
-
+#if GTK_CHECK_VERSION(2,18,0)
+        gdk_window_get_origin (gtk_widget_get_window (mgtim->priv->date_button), &x, &y);
+	GtkAllocation alloc;
+	gtk_widget_get_allocation (mgtim->priv->date_button, &alloc);
+        x += alloc.x;
+        y += alloc.y;
+        bwidth = alloc.width;
+        bheight = alloc.height;
+#else
+	gdk_window_get_origin (mgtim->priv->date_button->window, &x, &y);
+	
         x += mgtim->priv->date_button->allocation.x;
         y += mgtim->priv->date_button->allocation.y;
         bwidth = mgtim->priv->date_button->allocation.width;
-        bheight = mgtim->priv->date_button->allocation.height;
+	bheight = mgtim->priv->date_button->allocation.height;
+#endif
 
         x += bwidth - req.width;
         y += bheight;
@@ -894,6 +1011,8 @@ position_popup (GdauiEntryCommonTime *mgtim)
 /*
  * callbacks for the time
  */
+static void entry_time_insert_func (GdauiFormattedEntry *fentry, gunichar insert_char, gint virt_pos, gpointer data);
+
 static GtkWidget *
 create_entry_time (GdauiEntryCommonTime *mgtim)
 {
@@ -902,14 +1021,23 @@ create_entry_time (GdauiEntryCommonTime *mgtim)
 
 	/* text entry */
 	dh = gdaui_data_entry_get_handler (GDAUI_DATA_ENTRY (mgtim));
-        wid = gdaui_format_entry_new ();
 	if (GDA_IS_HANDLER_TIME (dh)) {
-		gchar *str;
+		gchar *str, *mask, *ptr;
 		str = gda_handler_time_get_format (GDA_HANDLER_TIME (dh), GDA_TYPE_TIME);
-		gdaui_format_entry_set_format (GDAUI_FORMAT_ENTRY (wid), str, NULL, NULL);
-		gtk_entry_set_width_chars (GTK_ENTRY (wid), g_utf8_strlen (str, -1));
+		mask = g_strdup (str);
+		for (ptr = mask; *ptr; ptr++) {
+			if (*ptr == '0')
+				*ptr = '-';
+		}
+		wid = gdaui_formatted_entry_new (str, mask);
 		g_free (str);
+		g_free (mask);
+
+		gdaui_formatted_entry_set_insert_func (GDAUI_FORMATTED_ENTRY (wid), entry_time_insert_func,
+						       mgtim);
 	}
+	else
+		wid = gdaui_entry_new (NULL, NULL);
         mgtim->priv->entry_time = wid;
 
         /* format tooltip */
@@ -918,6 +1046,41 @@ create_entry_time (GdauiEntryCommonTime *mgtim)
         return wid;
 }
 
+static void
+entry_time_insert_func (GdauiFormattedEntry *fentry, gunichar insert_char, gint virt_pos, gpointer data)
+{
+	GValue *value;
+	GType type;
+
+	type = gdaui_data_entry_get_value_type (GDAUI_DATA_ENTRY (data));
+	value = real_get_value (GDAUI_ENTRY_WRAPPER (data));
+	if (!value)
+		return;
+
+	if ((type == GDA_TYPE_TIME) && 
+	    (insert_char == g_utf8_get_char (" "))) {
+		/* set current time */
+		gda_value_reset_with_type (value, type);
+		struct tm *ltm;
+		time_t val;
+		
+		val = time (NULL);
+		ltm = localtime ((const time_t *) &val);
+		if (ltm) {
+			GdaTime tim;
+			memset (&tim, 0, sizeof (GdaTime));
+			tim.hour = ltm->tm_hour;
+			tim.minute = ltm->tm_min;
+			tim.second = ltm->tm_sec;
+			tim.fraction = 0;
+			tim.timezone = GDA_TIMEZONE_INVALID;
+			gda_value_set_time (value, (const GdaTime *) &tim);
+			real_set_value (GDAUI_ENTRY_WRAPPER (data), value);
+		}
+	}
+	
+	gda_value_free (value);
+}
 
 /*
  * callbacks for the timestamp
@@ -966,11 +1129,11 @@ gdaui_entry_common_time_start_editing (GtkCellEditable *iface, GdkEvent *event)
 {
 	GdauiEntryCommonTime *mgtim;
 
-	g_return_if_fail (iface && GDAUI_IS_ENTRY_COMMON_TIME (iface));
+	g_return_if_fail (GDAUI_IS_ENTRY_COMMON_TIME (iface));
 	mgtim = GDAUI_ENTRY_COMMON_TIME (iface);
 	g_return_if_fail (mgtim->priv);
 
-
+	mgtim->priv->editing_canceled = FALSE;
 	if (mgtim->priv->date_button) {
 		gtk_widget_destroy (mgtim->priv->date_button);
 		mgtim->priv->date_button = NULL;
@@ -982,20 +1145,20 @@ gdaui_entry_common_time_start_editing (GtkCellEditable *iface, GdkEvent *event)
 	}
 
 	if (mgtim->priv->entry_date) {
-		g_object_set (G_OBJECT (mgtim->priv->entry_date), "has_frame", FALSE, NULL);
+		g_object_set (G_OBJECT (mgtim->priv->entry_date), "has-frame", FALSE, NULL);
 		gtk_cell_editable_start_editing (GTK_CELL_EDITABLE (mgtim->priv->entry_date), event);
-		g_signal_connect (G_OBJECT (mgtim->priv->entry_date), "editing_done",
+		g_signal_connect (G_OBJECT (mgtim->priv->entry_date), "editing-done",
 				  G_CALLBACK (gtk_cell_editable_entry_editing_done_cb), mgtim);
-		g_signal_connect (G_OBJECT (mgtim->priv->entry_date), "remove_widget",
+		g_signal_connect (G_OBJECT (mgtim->priv->entry_date), "remove-widget",
 				  G_CALLBACK (gtk_cell_editable_entry_remove_widget_cb), mgtim);
 	}
 
 	if (mgtim->priv->entry_time) {
-		g_object_set (G_OBJECT (mgtim->priv->entry_time), "has_frame", FALSE, NULL);
+		g_object_set (G_OBJECT (mgtim->priv->entry_time), "has-frame", FALSE, NULL);
 		gtk_cell_editable_start_editing (GTK_CELL_EDITABLE (mgtim->priv->entry_time), event);
-		g_signal_connect (G_OBJECT (mgtim->priv->entry_time), "editing_done",
+		g_signal_connect (G_OBJECT (mgtim->priv->entry_time), "editing-done",
 				  G_CALLBACK (gtk_cell_editable_entry_editing_done_cb), mgtim);
-		g_signal_connect (G_OBJECT (mgtim->priv->entry_time), "remove_widget",
+		g_signal_connect (G_OBJECT (mgtim->priv->entry_time), "remove-widget",
 				  G_CALLBACK (gtk_cell_editable_entry_remove_widget_cb), mgtim);
 	}
 
